@@ -6,8 +6,8 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
-ln -fs "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
+ln -s "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist || true
 
 ../../src/dnscap -w test3.pcap -r dns.pcap-dist -P "$plugin" -k "some 16-byte key" -i "some 16-byte key" -a "some 16-byte key" 2>test3.out
 ../../src/dnscap -w test3.pcap -r dns6.pcap-dist -P "$plugin" -k "some 16-byte key" -i "some 16-byte key" -a "some 16-byte key" -6 2>>test3.out
