@@ -6,7 +6,7 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
 
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" 2>test1.out || true
 if grep -q "no cryptopANT support built in" test1.out 2>/dev/null; then
@@ -21,7 +21,7 @@ fi
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -k "$srcdir/keyfile" -s 2>>test1.out
 ! ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -k "$srcdir/keyfile" -c -s 2>>test1.out
 
-ln -fs "$srcdir/../../src/test/edns.pcap" edns.pcap-dist
+ln -s "$srcdir/../../src/test/edns.pcap" edns.pcap-dist || true
 
 ../../src/dnscap -r edns.pcap-dist -g -P "$plugin" -k "$srcdir/keyfile" -4 8 -e 2>>test1.out
 ../../src/dnscap -r edns.pcap-dist -g -P "$plugin" -k "$srcdir/keyfile" -4 8 -E 2>>test1.out
