@@ -6,7 +6,7 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist
+ln -s "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist || true
 
 ../../src/dnscap -r dns6.pcap-dist -g -P "$plugin" 2>test2.out || true
 if grep -q "no cryptopANT support built in" test2.out 2>/dev/null; then
