@@ -6,8 +6,8 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
-ln -fs "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
+ln -s "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist || true
 
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" 2>test3.out || true
 if grep -q "no cryptopANT support built in" test3.out 2>/dev/null; then
