@@ -6,9 +6,9 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
-ln -fs "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist
-ln -fs "$srcdir/../../src/test/dnso1tcp.pcap" dnso1tcp.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
+ln -s "$srcdir/../../src/test/dns6.pcap" dns6.pcap-dist || true
+ln -s "$srcdir/../../src/test/dnso1tcp.pcap" dnso1tcp.pcap-dist || true
 
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -?
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin"
