@@ -6,7 +6,7 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
 
 ! ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" 2>test1.out
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -k "some 16-byte key" 2>>test1.out
@@ -14,7 +14,7 @@ ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -k "some 16-byte key" -s 2>>test1.out
 ! ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -k "some 16-byte key" -c -s 2>>test1.out
 
-ln -fs "$srcdir/../../src/test/edns.pcap" edns.pcap-dist
+ln -s "$srcdir/../../src/test/edns.pcap" edns.pcap-dist || true
 
 ../../src/dnscap -r edns.pcap-dist -g -P "$plugin" -k "some 16-byte key" -e 2>>test1.out
 ../../src/dnscap -r edns.pcap-dist -g -P "$plugin" -k "some 16-byte key" -E 2>>test1.out
