@@ -6,7 +6,7 @@ if [ -z "$plugin" ]; then
     exit 1
 fi
 
-ln -fs "$srcdir/../../src/test/dns.pcap" dns.pcap-dist
+ln -s "$srcdir/../../src/test/dns.pcap" dns.pcap-dist || true
 
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin" -?
 ../../src/dnscap -r dns.pcap-dist -g -P "$plugin"
