@@ -35,7 +35,7 @@
 #ifndef __dnscap_dnscap_h
 #define __dnscap_dnscap_h
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__hurd__)
 #define _GNU_SOURCE
 #define _FILE_OFFSET_BITS 64 /* for fopencookie() */
 #endif
@@ -55,7 +55,7 @@
 #include <pthread.h>
 #endif
 
-#ifdef __linux__
+#if defined(__linux__) || defined(__hurd__)
 #define __FAVOR_BSD
 #include <net/ethernet.h>
 #ifdef USE_SECCOMP
