@@ -37,6 +37,9 @@
 
 #include <netinet/in.h>
 #include <sys/types.h>
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE
+#endif
 #include <time.h>
 
 /* Macros for printing timeval */
