@@ -388,11 +388,11 @@ int main(int argc, char** argv)
 
     sa.sa_handler = stop;
     sigfillset(&sa.sa_mask);
-    if (sigaction(SIGINT, &sa, 0)) {
+    if ((ret = sigaction(SIGINT, &sa, 0))) {
         fprintf(stderr, "sigaction(SIGINT) error %d: %s\n", errno, strerror(errno));
         exit(4);
     }
-    if (sigaction(SIGHUP, &sa, 0)) {
+    if ((ret = sigaction(SIGHUP, &sa, 0))) {
         fprintf(stderr, "sigaction(SIGHUP) error %d: %s\n", errno, strerror(errno));
         exit(4);
     }
@@ -623,9 +623,7 @@ int main(int argc, char** argv)
             if (ret == PCAP_THREAD_OK)
                 ret = pcap_thread_set_use_layers(&pt, 1);
 
-#ifndef __clang_analyzer__
             layers = 1;
-#endif
             break;
         case 'F':
             if (!strcmp("4", optarg))
@@ -801,7 +799,6 @@ int main(int argc, char** argv)
         pcap_thread_set_timedrun(&pt, tv);
     }
 
-#ifndef __clang_analyzer__
     if (filterp != filter && (ret = pcap_thread_set_filter(&pt, filter, filterp - filter)))
         fprintf(stderr, "filter ");
     else if (!layers && (ret = pcap_thread_set_callback(&pt, callback)))
@@ -815,7 +812,6 @@ int main(int argc, char** argv)
     else if (layers && defrag_ipv6 && (ret = pcap_thread_set_callback_ipv6_frag(&pt, pcap_thread_ext_frag_layer_callback(&ipv6_frag_conf))))
         fprintf(stderr, "set callback ipv6 frag ");
     else {
-#endif
         for (i = 0; i < interface; i++) {
             if (is_file[i]) {
                 if (verbose)
@@ -859,9 +855,7 @@ int main(int argc, char** argv)
         if (pcap_thread_activate_mode(&pt) == PCAP_THREAD_ACTIVATE_MODE_DELAYED && pcap_thread_filter_errno(&pt)) {
             printf("non-fatal filter errno [%d]: %s\n", pcap_thread_filter_errno(&pt), strerror(pcap_thread_filter_errno(&pt)));
         }
-#ifndef __clang_analyzer__
     }
-#endif
 
     if (ret == PCAP_THREAD_EPCAP) {
         fprintf(stderr, "pcap error [%d]: %s (%s)\n", pcap_thread_status(&pt), pcap_statustostr(pcap_thread_status(&pt)), pcap_thread_errbuf(&pt));
