@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e dns.pcap || ln -s "$srcdir/dns.pcap" dns.pcap
+ln -s "$srcdir/dns.pcap" dns.pcap || true
 
 ../dnscap -?
 ! ../dnscap -j
