@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e dns.pcap || ln -s "$srcdir/dns.pcap" dns.pcap
+ln -s "$srcdir/dns.pcap" dns.pcap || true
 
 echo "-- only 1" >test14.out
 ../dnscap -g -q 1 -r dns.pcap 2>>test14.out
