@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e dns.pcap || ln -s "$srcdir/dns.pcap" dns.pcap
+ln -s "$srcdir/dns.pcap" dns.pcap || true
 
 ../dnscap -g -r dns.pcap 2>no-layers.out
 ../dnscap -g -r dns.pcap -o use_layers=yes 2>layers.out
