@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e frags.pcap || ln -s "$srcdir/frags.pcap" frags.pcap
+ln -s "$srcdir/frags.pcap" frags.pcap || true
 
 ../dnscap -g -f -r frags.pcap -o use_layers=yes -o defrag_ipv4=yes -o max_ipv4_fragments_per_packet=64 2>frags.out
 
