@@ -5,7 +5,7 @@ txtout="../../plugins/txtout/.libs/txtout.so"
 rm -f test7.out test7.layer.out
 
 for what in dnso1tcp.pcap 1qtcpnosyn.pcap do1t-nosyn-1nolen.pcap dnso1tcp-midmiss.pcap; do
-    test -e "$what" || ln -s "$srcdir/$what" "$what"
+    ln -s "$srcdir/$what" "$what" || true
 
     ../dnscap -r "$what" -g -T 2>>test7.out
     ../dnscap -r "$what" -g -T -o use_layers=yes 2>>test7.layer.out
@@ -23,7 +23,7 @@ echo "Enabling parse_ongoing_tcp and allow_reset_tcpstate" >>test7.layer.out
 echo "" >>test7.layer.out
 
 for what in dnso1tcp.pcap 1qtcpnosyn.pcap do1t-nosyn-1nolen.pcap dnso1tcp-midmiss.pcap; do
-    test -e "$what" || ln -s "$srcdir/$what" "$what"
+    ln -s "$srcdir/$what" "$what" || true
 
     ../dnscap -r "$what" -g -T -o parse_ongoing_tcp=yes -o allow_reset_tcpstate=yes 2>>test7.out
     ../dnscap -r "$what" -g -T -o parse_ongoing_tcp=yes -o allow_reset_tcpstate=yes -o use_layers=yes 2>>test7.layer.out
