@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e edns.pcap || ln -s "$srcdir/edns.pcap" edns.pcap
+ln -s "$srcdir/edns.pcap" edns.pcap || true
 
 ../dnscap -g -r edns.pcap 2>edns.out
 
