@@ -1,7 +1,7 @@
 #!/bin/sh -xe
 
-test -e ether_padd.pcap || ln -s "$srcdir/ether_padd.pcap" ether_padd.pcap
-test -e ipv6-with-ethernet-padding.pcap || ln -s "$srcdir/ipv6-with-ethernet-padding.pcap" ipv6-with-ethernet-padding.pcap
+ln -s "$srcdir/ether_padd.pcap" ether_padd.pcap || true
+ln -s "$srcdir/ipv6-with-ethernet-padding.pcap" ipv6-with-ethernet-padding.pcap || true
 
 ../dnscap -T -u 443 -g -r ether_padd.pcap 2>ether_padd.out
 ../dnscap -T -g -r ipv6-with-ethernet-padding.pcap 2>>ether_padd.out
