@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e icmp.pcap || ln -s "$srcdir/icmp.pcap" icmp.pcap
+ln -s "$srcdir/icmp.pcap" icmp.pcap || true
 
 ../dnscap -g -I -r icmp.pcap 2>test_icmp.out
 
