@@ -1,6 +1,6 @@
 #!/bin/sh -xe
 
-test -e sll2.pcap || ln -s "$srcdir/sll2.pcap" sll2.pcap
+ln -s "$srcdir/sll2.pcap" sll2.pcap || true
 
 ../dnscap -g -r sll2.pcap 2>sll2.out
 
